<?php

namespace Epin\Litecms\Policies;

use Litepie\User\Contracts\UserPolicy;
use Epin\Litecms\Models\Epin;

class EpinPolicy
{

    /**
     * Determine if the given user can view the epin.
     *
     * @param UserPolicy $user
     * @param Epin $epin
     *
     * @return bool
     */
    public function view(UserPolicy $user, Epin $epin)
    {
        if ($user->canDo('litecms.epin.view') && $user->isAdmin()) {
            return true;
        }

        return $epin->user_id == user_id() && $epin->user_type == user_type();
    }

    /**
     * Determine if the given user can create a epin.
     *
     * @param UserPolicy $user
     * @param Epin $epin
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('litecms.epin.create');
    }

    /**
     * Determine if the given user can update the given epin.
     *
     * @param UserPolicy $user
     * @param Epin $epin
     *
     * @return bool
     */
    public function update(UserPolicy $user, Epin $epin)
    {
        if ($user->canDo('litecms.epin.edit') && $user->isAdmin()) {
            return true;
        }

        return $epin->user_id == user_id() && $epin->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given epin.
     *
     * @param UserPolicy $user
     * @param Epin $epin
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Epin $epin)
    {
        return $epin->user_id == user_id() && $epin->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given epin.
     *
     * @param UserPolicy $user
     * @param Epin $epin
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Epin $epin)
    {
        if ($user->canDo('litecms.epin.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given epin.
     *
     * @param UserPolicy $user
     * @param Epin $epin
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Epin $epin)
    {
        if ($user->canDo('litecms.epin.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
