<?php

namespace Epin\Litecms\Providers;

use Illuminate\Support\ServiceProvider;

class LitecmsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'litecms');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'litecms');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('epin.litecms', function ($app) {
            return $this->app->make('Epin\Litecms\Litecms');
        });

                // Bind Epin to repository
        $this->app->bind(
            'Epin\Litecms\Interfaces\EpinRepositoryInterface',
            \Epin\Litecms\Repositories\Eloquent\EpinRepository::class
        );

        $this->app->register(\Epin\Litecms\Providers\AuthServiceProvider::class);
                $this->app->register(\Epin\Litecms\Providers\EventServiceProvider::class);
        
        $this->app->register(\Epin\Litecms\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['epin.litecms'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('epin/litecms.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/litecms')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/litecms')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
